MCPcopy Create free account
hub / github.com/NGSolve/ngsolve / RunAll

Function RunAll

ngscuda/cuda_tasks.cpp:118–125  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

116// #ifdef __CUDACC__
117
118__global__ void RunAll() // int n, F f)
119{
120 int bid = blockIdx.x;
121 if (bid == 0)
122 ; // RunParallel (10, [] __device__ (int nr, int size) { ; });
123 else
124 Worker();
125}
126
127__host__ void StartDeviceJob()
128{

Callers

nothing calls this directly

Calls 1

WorkerFunction · 0.85

Tested by

no test coverage detected